@@ -16,6 +16,7 @@ use crate::{
 };
 use bytes::Bytes;
 use std::{
+    cmp,
     collections::HashMap,
     error::Error,
     ffi::CString,
@@ -558,12 +559,12 @@ impl<T: Send> Session<T> {
             opts: mut mta_opts,
         } = OptNegPayload::parse_buffer(buffer)?;
 
-        // Note: this is different from libmilter. We only support protocol
-        // versions 6 (and up). Older versions are not supported.
-        if mta_version < PROTOCOL_VERSION {
+        if mta_version < 2 {
             return Err(SessionError::ProtocolVersionNotSupported(mta_version));
         }
 
+        let target_version = cmp::min(mta_version, PROTOCOL_VERSION);
+
         if mta_actions.is_empty() {
             mta_actions = Actions::min_flags();
         }
@@ -620,13 +621,8 @@ impl<T: Send> Session<T> {
             return Err(SessionError::ProtoOptsNotSupported(target_opts));
         }
 
-        self.write_opt_neg_reply(
-            PROTOCOL_VERSION,
-            self.actions,
-            target_opts,
-            requested_macros,
-        )
-        .await?;
+        self.write_opt_neg_reply(target_version, self.actions, target_opts, requested_macros)
+            .await?;
 
         Ok(())
     }
