@@ -4,8 +4,8 @@ pub use crate::common::*;
 use byte_strings::c_str;
 use indymilter::{
     message::{
-        commands::{Command, ConnInfoPayload, OptNegPayload},
-        replies::Reply,
+        command::{Command, ConnInfoPayload, OptNegPayload},
+        reply::Reply,
         PROTOCOL_VERSION,
     },
     Actions, Callbacks, Config, ProtoOpts, SocketInfo, Status,
@@ -23,7 +23,7 @@ use std::{
 };
 use tokio::time;
 
-#[derive(Clone, Copy, Debug)]
+#[derive(Debug)]
 enum Stage {
     Connect,
     Close,
@@ -41,7 +41,7 @@ async fn max_connections() {
 
     let config = Config {
         max_connections,
-        ..Default::default()
+        ..default_config()
     };
 
     let events = Arc::new(Mutex::new(Vec::new()));
