@@ -1,11 +1,11 @@
 local conn = mt.connect("inet:" .. port .. "@127.0.0.1")
 assert(conn, "could not open connection")
 
-local err = mt.conninfo(conn, "client.amy.org", "123.123.123.123")
+local err = mt.conninfo(conn, "mail.example.org", "123.123.123.123")
 assert(err == nil, err)
 assert(mt.getreply(conn) == SMFIR_CONTINUE)
 
-local err = mt.helo(conn, "client.amy.org")
+local err = mt.helo(conn, "mail.example.org")
 assert(err == nil, err)
 assert(mt.getreply(conn) == SMFIR_CONTINUE)
 
@@ -13,7 +13,7 @@ local err = mt.eom(conn)
 assert(err == nil, err)
 assert(mt.getreply(conn) == SMFIR_CONTINUE)
 
-assert(mt.eom_check(conn, MT_HDRADD, "name", "value"));
+assert(mt.eom_check(conn, MT_HDRADD, "name1", "value1"));
 assert(mt.eom_check(conn, MT_HDRADD, "name2", "value2"));
 
 local err = mt.disconnect(conn)
